Named character vector of header field values
(except Authorization, which is handled via .token). This can be
used to override or augment the default User-Agent header:
"https://github.com/r-lib/gh".
Details
Note that these are not always defined. E.g. if the first
page was queried (the default), then there are no first and previous
pages defined. If there is no next page, then there is no
next page defined, etc.
If the requested page does not exist, an error is thrown.
See Also
The .limit argument to gh() supports fetching more than
one page.